
#include "board.h"



typedef struct {
   unsigned char bLength;
   unsigned char bDescriptorType;
   unsigned short bcdUSB;
   unsigned char bDeviceClass;
   unsigned char bDeviceSubClass;
   unsigned char bDeviceProtocol;
   unsigned char bMaxPacketSize0;
   unsigned short idVendor;
   unsigned short idProduct;
   unsigned short bcdDevice;
   unsigned char iManufacturer;
   unsigned char iProduct;
   unsigned char iSerialNumber;
   unsigned char bNumConfigurations;
} __attribute__ ((packed)) USBDeviceDescriptor; // GCC

typedef struct {
   unsigned char bLength;
   unsigned char bDescriptorType;
   unsigned short wTotalLength;
   unsigned char bNumInterfaces;
   unsigned char bConfigurationValue;
   unsigned char iConfiguration;
   unsigned char bmAttributes;
   unsigned char bMaxPower;
} __attribute__ ((packed)) USBConfigurationDescriptor; // GCC


typedef struct {
   unsigned char bLength;
   unsigned char bDescriptorType;
   unsigned short bcdUSB;
   unsigned char bDeviceClass;
   unsigned char bDeviceSubClass;
   unsigned char bDeviceProtocol;
   unsigned char bMaxPacketSize0;
   unsigned char bNumConfigurations;
   unsigned char bReserved;
} __attribute__ ((packed)) USBDeviceQualifierDescriptor; // GCC


#define USBStringDescriptor_ENGLISH_US          0x09, 0x04
#define USBStringDescriptor_LENGTH(length)      ((length) * 2 + 2)
#define USBStringDescriptor_UNICODE(ascii)      (ascii), 0

#define USBGenericDescriptor_STRING                     3

// Language ID string descriptor
const unsigned char languageIdStringDescriptor[] = {
    USBStringDescriptor_LENGTH(1),
    USBGenericDescriptor_STRING,
    USBStringDescriptor_ENGLISH_US
};

// Product string descriptor
const unsigned char productStringDescriptor[] = {
    USBStringDescriptor_LENGTH(4),
    USBGenericDescriptor_STRING,
    USBStringDescriptor_UNICODE('U'),
    USBStringDescriptor_UNICODE('S'),
    USBStringDescriptor_UNICODE('B'),
    USBStringDescriptor_UNICODE('T'),
    USBStringDescriptor_UNICODE('e'),
    USBStringDescriptor_UNICODE('s'),
    USBStringDescriptor_UNICODE('t')
};


/// List of string descriptors used by the device
const unsigned char *stringDescriptors[] = {
    languageIdStringDescriptor,
    productStringDescriptor,
};


typedef struct {
    const USBDeviceDescriptor *pFsDevice;                   /// Pointer to the full-speed device descriptor.
    const USBConfigurationDescriptor *pFsConfiguration;     /// Pointer to the full-speed configuration descriptor.
    const USBDeviceQualifierDescriptor *pFsQualifier;       /// Pointer to the full-speed qualifier descriptor.
    const USBConfigurationDescriptor *pFsOtherSpeed;        /// Pointer to the full-speed other speed configuration descriptor.
    const USBDeviceDescriptor *pHsDevice;                   /// Pointer to the high-speed device descriptor.
    const USBConfigurationDescriptor *pHsConfiguration;     /// Pointer to the high-speed configuration descriptor.
    const USBDeviceQualifierDescriptor *pHsQualifier;       /// Pointer to the high-speed qualifier descriptor.
    const USBConfigurationDescriptor *pHsOtherSpeed;        /// Pointer to the high-speed other speed configuration descriptor.
    const unsigned char **pStrings;                         /// Pointer to the list of string descriptors.
    const unsigned char numStrings;                         /// Number of string descriptors in list.
} USBDDriverDescriptors;


/// List of standard descriptors for the serial driver.
const USBDDriverDescriptors cdcdSerialDriverDescriptors = {
    (USBDeviceDescriptor*) (10),
    (USBConfigurationDescriptor*) (20),
    0, // No full-speed device qualifier descriptor
    0, // No full-speed other speed configuration
    0, // No high-speed device descriptor
    0, // No high-speed configuration descriptor
    0, // No high-speed device qualifier descriptor
    0, // No high-speed other speed configuration descriptor
    stringDescriptors,
    2 // 2 string descriptors in list
};



int main(void)
{
  // dummy reference to keep this from being optimized
  int i = (int)&cdcdSerialDriverDescriptors;
  return i;
  
}
